%
% DEMOOKECA Demo that compares the estimation of PDF and the classification accuracy between KECA and OKECA methods
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra,
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

clear all
close all
clc

warning off

rand('seed',2222)
randn('seed',2222)

%% Include paths
addpath(genpath('./methods'))
addpath(genpath('./tools'))

%% Load Data
disp('1/ Loading data ...')
datos='moons';
Ntr = 50;

[X,Y,X2,cl,Ndom]=loadData(Ntr);

%% Estimate sigmas
disp('2/ Estimating sigma lengthscale ...')
SIGMAS = estimateSigma4(X);

t=0;
K_KECA = [];    K_KECA2 = [];
for sigma=[SIGMAS{4} 0.15*SIGMAS{4} mean(SIGMAS{6}) SIGMAS{7}]
    t=t+1;
    disp(['   SIGMA ' num2str(t) ': ' num2str(sigma)])
    
    disp('   - Constructing kernel ...')
    % Compute the kernel matrix
    n1sq = sum(X.^2);
    n1 = size(X,2);
    D = (ones(n1,1)*n1sq)' + ones(n1,1)*n1sq -2*X'*X;
    
    K = (1/size(X,1))*(1/(sigma*sqrt(2*pi)))*exp(-D/(2*sigma^2));
    
    disp('   - Calculating OKECA eigendecomposition ...')
    % Feature Extraction with OKECA
    [A,D1]=okeca(K);
    
    Vkeca2(:,:,t) = A;
    Etrp2(t,:) = sum(A).^2;
    
    disp('   - Calculating KECA eigendecomposition ...')
    % Feature Extraction with KECA
    [V,D]=keca(K);
    
    valores_keca = sum((V*(D.^0.5))).^2;
    
    Vkeca(:,:,t) = V;
    Etrp(t,:) = valores_keca;
    
    % Estimation of the PDFs (Original, KECA, OKECA)
    [PDFor,P1,P2]=PDFestimation(X,X2,sigma,V,A);
    
    PDForiginal(t,:) = PDFor;
    PDFkeca(:,:,t) = P1;
    PDFkeca2(:,:,t) = P2;
    
    %% classify
    Ntest =500;
    
    [X3,Y3,X2,cl,Ndom]=loadData(Ntest);
    
    Nreal=10;
    disp(['   - Classifying for ' num2str(Nreal) ' realizations ...'])
    for NN=1:Nreal
        ii1=[];
        for t1=1:cl
            incl=find(Y==t1);
            ii = randperm(length(incl));
            
            ii1 = [ii1 incl(ii(1:20))];
        end
        X1 = X(:,ii1);
        
        Y1 = Y(ii1);
        
        [K_t,VPR,APR,KCL] = KECAclass(X1,Y1,X3,sigma);
        
        for d=1:20
            
            [YpredKECA,YpredKECA2]=ProbabilityPredict(VPR,APR,K_t,d);
            
            kecaS=assessment(Y3,YpredKECA,'class');
            keca2=assessment(Y3,YpredKECA2,'class');
            
            RESkeca(NN,d,t) = kecaS.OA;
            RESokeca(NN,d,t) = keca2.OA;
        end
    end
    
end

figures(Etrp,Etrp2,PDForiginal,PDFkeca,PDFkeca2,Ndom,RESkeca,RESokeca)

