%
% Generates kernels test and computes the eigendecomposition of KECA 
% and OKECA per class.
% Inputs:  - X:       Training data matrix (size:[dxM])
%          - Y:       Array of training labels (size:[1xM])       
%          - X3:      Test data matrix (size:[dxM])
%          - sigma:   sigma parameter. (scalar).
% Outputs: - K_test1: Kernel test per class
%          - V:       KECA eigenvectors per class
%          - A1:      OKECA eigenvectors per class
%          - Kcl:     Kernel train per class
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra, 
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

function [K_test1,V,A1,Kcl] = KECAclass(X,Y,X3,sigma)

clase=unique(Y);

for cl=1:length(clase)

    % Kernel train per class
    n1sq = sum(X(:,Y==clase(cl)).^2);
    n1 = size(X(:,Y==clase(cl)),2);
    D = (ones(n1,1)*n1sq)' + ones(n1,1)*n1sq -2*X(:,(Y==clase(cl)))'*X(:,(Y==clase(cl)));
    
    Kcl1 = (1/size(X(:,Y==clase(cl)),1))*(1/(sigma*sqrt(2*pi)))*exp(-D/(2*sigma^2));
    Kcl(:,:,cl)=Kcl1;
    
    % Kernel test per class
    n1sq = sum(X(:,Y==clase(cl)).^2);
    n1 = size(X(:,Y==clase(cl)),2);
    
    n2sq = sum(X3.^2,1);
    n2 = size(X3,2);
    D = (ones(n2,1)*n1sq)' + ones(n1,1)*n2sq -2*X(:,Y==clase(cl))'*X3;
    
    K_test1(:,:,cl) = (1/size(X(:,Y==clase(cl)),1))*(1/(sigma*sqrt(2*pi)))*exp(-D/(2*sigma^2));
    
     % Feature Extraction with OKECA per class
    [A,D1]=okeca(Kcl1);

    A1(:,:,cl) = A;
    
    % Feature Extraction with KECA per class
    [V1,D]=keca(Kcl1);
    
    V(:,:,cl)=V1;
end
