% PDFESTIMATION Estimates PDF of the data in the original domain, and the PDF estimation using KECA and OKECA methods.
%
% Inputs:  - X:           Training data matrix (size:[dxM])
%          - X2:          PDF evaluation matrix (size:[NdomxNdom])
%          - sigma:       Sigma value (scalar)
%          - V:           KECA eigenvectors (size:[MxM])
%          - A:           OKECA eigenvectors (size:[MxM])
% Outputs: - PDForiginal: PDF estimates using original data
%          - P_KECA:      PDF estimates using KECA method
%          - P_KECA2:     PDF estimates using OKECA method
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra, 
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

function [PDForiginal,P_KECA,P_KECA2]=PDFestimation(X,X2,sigma,V,A)

% Computing Kernel test
n1sq = sum(X.^2);
n1 = size(X,2);

n2sq = sum(X2.^2,1);
n2 = size(X2,2);
D = (ones(n2,1)*n1sq)' + ones(n1,1)*n2sq -2*X'*X2;

K_test = (1/size(X,1))*(1/(sigma*sqrt(2*pi)))*exp(-D/(2*sigma^2));

% Estimation of the original PDF
PDForiginal=sum(K_test);

%Estimation PDF using KECA y OKECA methods.
for m=1:5
    P_KECA(m,:) = sum(V(:,1:m)*V(:,1:m)'*K_test);
    P_KECA2(m,:) = sum(A(:,1:m)*pinv(A(:,1:m))*K_test);
end
