% PROBABILITYPREDICT Predicts the label arrays using KECA and OKECA methods in function of
% the probability per class
% Inputs:  - V1:      KECA eigenvectors (size:[MxM])
%          - A1:      OKECA eigenvectors (size:[MxM])
%          - K_test1: Kernel test per class
%          - d:       Number of features.
% Output: YpredKECA:  Array of KECA predicted labels (size:[1xM])
%         YpredKECA2: Array of OKECA predicted labels (size:[1xM])
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra, 
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

function [YpredKECA,YpredKECA2]=ProbabilityPredict(V1,A1,K_test1,d)


for cl=1:size(K_test1,3)
    P_KECA(cl,:) = sum(V1(:,1:d,cl)*V1(:,1:d,cl)'*K_test1(:,:,cl));
    P_KECA2(cl,:) = sum(A1(:,1:d,cl)*pinv(A1(:,1:d,cl))*K_test1(:,:,cl));
end

[val,YpredKECA]=max(P_KECA);
[val,YpredKECA2]=max(P_KECA2);

