%
% FIGURES Plot the PDF estimates and the Overall Accuracy of the classification.
%
% Inputs:  - Etrp:    Entropy values of KECA method.
%          - Etrp2:   Entropy values of OKECA method.       
%          - PDForig: PDF estimates using original data
%          - PDF1:    PDF estimates using KECA method
%          - PDF2:    PDF estimates using OKECA method
%          - K_KECA:  Overall Accuracy using KECA method
%          - K_KECA2: Overall Accuracy using OKECA method
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra, 
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

function figures(Etrp,Etrp2,PDForig,PDF1,PDF2,Ndom,K_KECA,K_KECA2)


fontname = 'Arial';
fontsize = 14;
fontunits = 'points';
set(0,'DefaultAxesFontName',fontname,'DefaultAxesFontSize',fontsize,'DefaultAxesFontUnits',fontunits,...
    'DefaultTextFontName',fontname,'DefaultTextFontSize',fontsize,'DefaultTextFontUnits',fontunits,...
    'DefaultLineLineWidth',3,'DefaultLineMarkerSize',8,'DefaultLineColor',[0 0 0]);

sigma_name={'\sigma_{d1}','\sigma_{d2}','\sigma_{Silv}','\sigma_{ML}'};
n_sig = size(K_KECA,3);
%% Cummulative Entropy
dim=10;
figure,
for d = 1:n_sig
    subplot(size(Etrp,1)/2,size(Etrp,1)/2,d), 
    semilogy(1:dim, cumsum(Etrp(d,1:dim)),'b','MarkerSize',12,'Marker','o')
    hold on, semilogy(1:dim, cumsum(Etrp2(d,1:dim)),'r','MarkerSize',12,'Marker','o')
    legend('KECA','OKECA'), grid
    title(sigma_name{d})
    axis([0 10 10 1000])
end


%% % Density Estimation original data


figure
for d = 1:n_sig
    PDForiginal=PDForig(d,:);
    subplot(size(PDForig,1)/2,size(PDForig,1)/2,d)
    imagesc(reshape(PDForiginal,Ndom,Ndom),[min(PDForiginal) max(PDForiginal)])
    colormap hot
    title(sigma_name{d})
    axis off
    axis equal
end

%% % Density Estimation KECA y KECA2
p=0;
figure,
for d =1:n_sig
    for m=1:5
        p=p+1;
        PDFkeca = PDF1(m,:,d);
        subplot(size(PDF1,3),size(PDF1,1),p)
        imagesc(reshape(PDFkeca,Ndom,Ndom),[min(PDForiginal) max(PDForiginal)])
        colormap hot
        axis off
        axis equal
        if d==1
            title(['#feat' num2str(m)])
        end
        if m==1
            ylabel(sigma_name{d})
        end
    end
end

p=0;
figure,
for d = 1:n_sig
    for m = 1:5
        p=p+1;
        PDFkeca2 = PDF2(m,:,d);
        subplot(size(PDF2,3),size(PDF2,1),p)
        imagesc(reshape(PDFkeca2,Ndom,Ndom),[min(PDForiginal) max(PDForiginal)])
        colormap hot
        axis off
        axis equal
        if d==1
            title(['#feat' num2str(m)])
        end
        if m==1
            ylabel(sigma_name{d})
        end
    end
end


%% % classify

if ~isempty(K_KECA)
    a=[];b=[];
    for d=1:n_sig
        a=[a (mean(K_KECA(:,:,d)))'];
        b=[b (mean(K_KECA2(:,:,d))-mean(K_KECA(:,:,d)))'];
    end
    P(:,:,1)=a;
    P(:,:,2)=b;
    
    plotBarStackGroups(P, {'1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20'})
    axis([0 21 0 100])
    xlabel('#Features')
    ylabel('OA[%]')
    legend('KECA','OKECA')
    
end
