%
% LOADDATA Generates original synthetic data
%
% Inputs:  - Ntr: Number of training samples
%
% Outputs: - X:   Training data matrix (size:[dxM])
%          - Y:   Array of training labels (size:[1xM])       
%          - X2:  PDF evaluation matrix (size:[NdomxNdom])
%          - cl:  Number of classes. (scalar)
%          - Ndom: maximum domain of PDF estimation matrix.
%
% Copyright (c) 2013  Emma Izquierdo-Verdiguier, Valero Laparra, 
%                     Robert Jenssen, Luis Gómez-Chova, and Gustavo Camps-Valls
%
%                     emma.izquierdo@uv.es, http://isp.uv.es
%

function [X,Y,X2,cl,Ndom]=loadData(Ntr)

Ns =Ntr/2;
dat1(1,:) = pi*rand(1,Ns);
dat1(2,:) = sin(dat1(1,:)) + 0.5*rand(1,Ns) - 0.5;
dat1(1,:) = dat1(1,:)/2;

dat2(1,:) = pi*rand(1,Ns) + pi/2;
dat2(2,:) = cos(dat2(1,:)) - 0.5*rand(1,Ns) + 0.5;
dat2(1,:) = dat2(1,:)/2;

Y=[ones(1,size(dat1,2)) 2*ones(1,size(dat2,2))];

X = [dat1 dat2];
cl = max(Y);
clear dat1 dat2

Ndom = 21;
XX1 = linspace(min(X(1,:)),max(X(1,:)),Ndom);
XX2 = linspace(min(X(2,:)),max(X(2,:)),Ndom);

[XX YY] = meshgrid(XX1,XX2);
X2 = [XX(:) YY(:)]';
